import asyncio, time, sys
from typing import List
from spider_rs import Website

async def main() -> None:
    print("benching spider-rs(python)...")
    url: str = len(sys.argv) > 1 and str(sys.argv[1]) or "https://rsseau.fr"
    website: Website = Website(url)
    start: float = time.time()
    website.crawl()
    end: float = time.time()
    links: List[str] = website.get_links()
    print(url, "pages found " + str(len(links)), "elapsed duration " + str(end - start) + "s", sep="\n")

asyncio.run(main())



import asyncio
from typing import List
from spider_rs import Website

async def main() -> None:
    website: Website = (
        Website("https://choosealicense.com", False)
        .with_user_agent("BotBot")
        .with_headers({"authorization": "Something "})
    )
    website.crawl()
    print(website.get_links())

asyncio.run(main())



import asyncio
import time
from typing import List
from spider_rs import Website

async def main() -> None:
    website: Website = Website("https://choosealicense.com", False)
    start_time: float = time.time()
    website.crawl()
    links: List[str] = website.get_links()
    print(links)
    print(f"time {time.time() - start_time}")

asyncio.run(main())



import asyncio
import time
from typing import Any
from spider_rs import Website

class Subscription:
    def __init__(self) -> None:
        print("Subscription Created...")
    
    def __call__(self, page: Any) -> None:
        print(f"{page.url} - status: {page.status_code}")

async def main() -> None:
    website: Website = Website("https://www.drake.com").with_budget({"*": 200})
    start_time: float = time.time()
    website.crawl(Subscription())
    print(f"time {time.time() - start_time}")

asyncio.run(main())



import asyncio
from typing import List
from spider_rs import crawl, Website

async def main() -> None:
    website: Website = await crawl("https://choosealicense.com")
    print(website.links)

asyncio.run(main())
